@@ -2,7 +2,7 @@ import sys
 import PyQt5
 from PyQt5 import QtCore, QtWidgets
 from PyQt5.QtWidgets import QWidget, QLabel, QAction, QTabWidget, QPushButton, QFileDialog, QRadioButton, QMessageBox, \
-    QComboBox, QLineEdit
+    QComboBox, QLineEdit, QSizePolicy
 from PyQt5.QtCore import QDateTime
 from PyQt5.QtGui import QIcon, QDoubleValidator
 from datetime import datetime, timedelta
@@ -64,8 +64,8 @@ class AnnotationWidget(QtWidgets.QWidget):
         self.axs[0].set_title("Preview")
         self.axs[1].set_title("Thematic Map")
 
-        toolbar = NavigationToolbar(canvas, self)
-        layout.addWidget(toolbar)
+        self.toolbar = NavigationToolbar(canvas, self)
+        layout.addWidget(self.toolbar)
         self.setLayout(layout)
 
         # add selection layer for lasso
@@ -76,6 +76,7 @@ class AnnotationWidget(QtWidgets.QWidget):
 
         lineprops = dict(color="red", linewidth=2)
         self.lasso = LassoSelector(self.axs[0], self.onlasso, lineprops=lineprops)
+        self.fig.tight_layout()
 
     def onlasso(self, verts):
         """
@@ -192,9 +193,8 @@ class AnnotationWidget(QtWidgets.QWidget):
         if event.inaxes == self.axs[1]:
             if event.button == 3:  # right click feature
                 self.draw_event_region_boundary(event)
-            if event.button == 1:
-                pass
-                # self.rename_region(event)
+            if event.button == 1 and self.toolbar.mode == "":
+                self.rename_region(event)
 
     def updateArray(self, array, indices, value):
         """
@@ -240,7 +240,9 @@ class AnnotationWidget(QtWidgets.QWidget):
         upper = np.nanpercentile(self.preview_data, upper_percentile)
         self.preview_data[self.preview_data < lower] = lower
         self.preview_data[self.preview_data > upper] = upper
-        self.preview_data /= np.nanmax(self.preview_data)
+        self.preview_data = (self.preview_data - np.nanmin(self.preview_data)) \
+                            / (np.nanmax(self.preview_data) - np.nanmin(self.preview_data))
+        # self.preview_data /= np.nanmax(self.preview_data)
         self.preview_axesimage.set_data(self.preview_data)
         self.fig.canvas.draw_idle()
 
@@ -271,8 +273,9 @@ class AnnotationWidget(QtWidgets.QWidget):
         self.preview_data[self.preview_data[:, :, 2] > blue_upper] = blue_upper
         
         for index in [0, 1, 2]:
-            self.preview_data[:, :, index] /= np.nanmax(self.preview_data[:, :, index])
-
+            # self.preview_data[:, :, index] /= np.nanmax(self.preview_data[:, :, index])
+            self.preview_data[:, :, index] = (self.preview_data[:, :, index] - np.nanmin(self.preview_data[:, :, index])) \
+                                / (np.nanmax(self.preview_data[:, :, index]) - np.nanmin(self.preview_data[:, :, index]))
         self.preview_axesimage.set_data(self.preview_data)
         self.fig.canvas.draw_idle()
 
@@ -317,7 +320,7 @@ class ControlWidget(QtWidgets.QWidget):
 
         self.one_color_min_editor = QLineEdit()
         self.one_color_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.one_color_min_editor.setText("0.0")
+        self.one_color_min_editor.setText("3.0")
         self.one_color_min_editor.editingFinished.connect(self.onSingleColorChange)
 
         self.one_color_max_editor = QLineEdit()
@@ -339,7 +342,6 @@ class ControlWidget(QtWidgets.QWidget):
         scale_label = QLabel("Scale", self)
         scale_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
 
-
         self.one_color_tab.setLayout(self.one_color_tab.layout)
         self.one_color_tab.layout.addWidget(channel_label, 0, 1)
         self.one_color_tab.layout.addWidget(min_label, 0, 2)
@@ -373,11 +375,11 @@ class ControlWidget(QtWidgets.QWidget):
         self.red_combo_box.currentTextChanged.connect(self.onThreeColorChange)
         self.red_min_editor = QLineEdit()
         self.red_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.red_min_editor.setText("0.0")
+        self.red_min_editor.setText("3.0")
         self.red_min_editor.editingFinished.connect(self.onThreeColorChange)
         self.red_max_editor = QLineEdit()
         self.red_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.red_max_editor.setText("100")
+        self.red_max_editor.setText("99.9")
         self.red_max_editor.editingFinished.connect(self.onThreeColorChange)
         self.red_scale_editor = QLineEdit()
         self.red_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
@@ -393,11 +395,11 @@ class ControlWidget(QtWidgets.QWidget):
         self.green_combo_box.currentTextChanged.connect(self.onThreeColorChange)
         self.green_min_editor = QLineEdit()
         self.green_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.green_min_editor.setText("0.0")
+        self.green_min_editor.setText("3.0")
         self.green_min_editor.editingFinished.connect(self.onThreeColorChange)
         self.green_max_editor = QLineEdit()
         self.green_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.green_max_editor.setText("100")
+        self.green_max_editor.setText("99.9")
         self.green_max_editor.editingFinished.connect(self.onThreeColorChange)
         self.green_scale_editor = QLineEdit()
         self.green_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
@@ -413,11 +415,11 @@ class ControlWidget(QtWidgets.QWidget):
         self.blue_combo_box.currentTextChanged.connect(self.onThreeColorChange)
         self.blue_min_editor = QLineEdit()
         self.blue_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.blue_min_editor.setText("0.0")
+        self.blue_min_editor.setText("3.0")
         self.blue_min_editor.editingFinished.connect(self.onThreeColorChange)
         self.blue_max_editor = QLineEdit()
         self.blue_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
-        self.blue_max_editor.setText("100")
+        self.blue_max_editor.setText("99.9")
         self.blue_max_editor.editingFinished.connect(self.onThreeColorChange)
         self.blue_scale_editor = QLineEdit()
         self.blue_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 3))
@@ -513,11 +515,9 @@ class ApplicationWindow(QtWidgets.QMainWindow):
             QtCore.Qt.Window |
             QtCore.Qt.CustomizeWindowHint |
             QtCore.Qt.WindowTitleHint |
-            QtCore.Qt.WindowCloseButtonHint |
-            QtCore.Qt.WindowStaysOnTopHint
+            QtCore.Qt.WindowCloseButtonHint
         )
 
-
     def initUI(self):
         self._main = QtWidgets.QWidget()
         self.setCentralWidget(self._main)
@@ -531,7 +531,6 @@ class ApplicationWindow(QtWidgets.QMainWindow):
         layout.addLayout(self.control_layout)
         self._setup_menubar()
 
-
     def _setup_control_layout(self):
         self.control_layout = QtWidgets.QHBoxLayout()
         self.controls = ControlWidget(self.annotator)
